==> verticalpodautoscaler-model-v1-6.7.2-sources.jar: io/fabric8/verticalpodautoscaler/api/model/v1/HistogramCheckpointBuilder.java <==
package io.fabric8.verticalpodautoscaler.api.model.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HistogramCheckpointBuilder extends HistogramCheckpointFluentImpl<HistogramCheckpointBuilder> implements VisitableBuilder<HistogramCheckpoint,HistogramCheckpointBuilder>{
  public HistogramCheckpointBuilder() {
    this(false);
  }
  public HistogramCheckpointBuilder(Boolean validationEnabled) {
    this(new HistogramCheckpoint(), validationEnabled);
  }
  public HistogramCheckpointBuilder(HistogramCheckpointFluent<?> fluent) {
    this(fluent, false);
  }
  public HistogramCheckpointBuilder(HistogramCheckpointFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HistogramCheckpoint(), validationEnabled);
  }
  public HistogramCheckpointBuilder(HistogramCheckpointFluent<?> fluent,HistogramCheckpoint instance) {
    this(fluent, instance, false);
  }
  public HistogramCheckpointBuilder(HistogramCheckpointFluent<?> fluent,HistogramCheckpoint instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withBucketWeights(instance.getBucketWeights());
      fluent.withReferenceTimestamp(instance.getReferenceTimestamp());
      fluent.withTotalWeight(instance.getTotalWeight());
    }
    this.validationEnabled = validationEnabled; 
  }
  public HistogramCheckpointBuilder(HistogramCheckpoint instance) {
    this(instance,false);
  }
  public HistogramCheckpointBuilder(HistogramCheckpoint instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withBucketWeights(instance.getBucketWeights());
      this.withReferenceTimestamp(instance.getReferenceTimestamp());
      this.withTotalWeight(instance.getTotalWeight());
    }
    this.validationEnabled = validationEnabled; 
  }
  HistogramCheckpointFluent<?> fluent;
  Boolean validationEnabled;
  public HistogramCheckpoint build() {
    HistogramCheckpoint buildable = new HistogramCheckpoint(fluent.getBucketWeights(),fluent.getReferenceTimestamp(),fluent.getTotalWeight());
    return buildable;
  }
  
}

==> verticalpodautoscaler-model-v1-6.8.0-sources.jar: io/fabric8/verticalpodautoscaler/api/model/v1/HistogramCheckpointBuilder.java <==
package io.fabric8.verticalpodautoscaler.api.model.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HistogramCheckpointBuilder extends HistogramCheckpointFluent<HistogramCheckpointBuilder> implements VisitableBuilder<HistogramCheckpoint,HistogramCheckpointBuilder>{
  public HistogramCheckpointBuilder() {
    this(false);
  }
  public HistogramCheckpointBuilder(Boolean validationEnabled) {
    this(new HistogramCheckpoint(), validationEnabled);
  }
  public HistogramCheckpointBuilder(HistogramCheckpointFluent<?> fluent) {
    this(fluent, false);
  }
  public HistogramCheckpointBuilder(HistogramCheckpointFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HistogramCheckpoint(), validationEnabled);
  }
  public HistogramCheckpointBuilder(HistogramCheckpointFluent<?> fluent,HistogramCheckpoint instance) {
    this(fluent, instance, false);
  }
  public HistogramCheckpointBuilder(HistogramCheckpointFluent<?> fluent,HistogramCheckpoint instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new HistogramCheckpoint());

    if (instance != null) {
      fluent.withBucketWeights(instance.getBucketWeights());
      fluent.withReferenceTimestamp(instance.getReferenceTimestamp());
      fluent.withTotalWeight(instance.getTotalWeight());
      fluent.withBucketWeights(instance.getBucketWeights());
      fluent.withReferenceTimestamp(instance.getReferenceTimestamp());
      fluent.withTotalWeight(instance.getTotalWeight());
    }
    this.validationEnabled = validationEnabled; 
  }
  public HistogramCheckpointBuilder(HistogramCheckpoint instance) {
    this(instance,false);
  }
  public HistogramCheckpointBuilder(HistogramCheckpoint instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new HistogramCheckpoint());

    if (instance != null) {
      this.withBucketWeights(instance.getBucketWeights());
      this.withReferenceTimestamp(instance.getReferenceTimestamp());
      this.withTotalWeight(instance.getTotalWeight());
      this.withBucketWeights(instance.getBucketWeights());
      this.withReferenceTimestamp(instance.getReferenceTimestamp());
      this.withTotalWeight(instance.getTotalWeight());
    }
    this.validationEnabled = validationEnabled; 
  }
  HistogramCheckpointFluent<?> fluent;
  Boolean validationEnabled;
  public HistogramCheckpoint build() {
    HistogramCheckpoint buildable = new HistogramCheckpoint(fluent.getBucketWeights(),fluent.getReferenceTimestamp(),fluent.getTotalWeight());
    return buildable;
  }
  
}
